@@ -17,7 +17,9 @@ class WialonUnit(WialonBase):
         :type name: :py:obj:`str`
         :param hw_type_id: A Wialon hardware type ID.
         :type hw_type_id: :py:obj:`str` | :py:obj:`int`
-        :returns: The Wialon id for the new unit.
+        :raises ValueError: If ``creator_id`` is a :py:obj:`str` but not a digit.
+        :raises ValueError: If ``hw_type_id`` is a :py:obj:`str` but not a digit.
+        :returns: An id for the new unit.
         :rtype: :py:obj:`int` | :py:obj:`None`
 
         """
@@ -45,33 +47,48 @@ class WialonUnit(WialonBase):
                     [flags.DATAFLAG_UNIT_ADVANCED_PROPERTIES, flags.DATAFLAG_UNIT_IMAGE]
                 ),
             }
-        ).get("item", {})
-        self._imei_number = response.get("uid")
-        self._active = response.get("act", False)
-        self._image_uri = response.get("uri")
+        )
+        if response is not None:
+            item = response.get("item", {})
+            self._imei_number = item.get("uid")
+            self._active = item.get("act", False)
+            self._image_uri = item.get("uri")
 
     def get_position(self) -> dict:
         return self.session.wialon_api.core_search_item(
             **{"id": self.id, "flags": flags.DATAFLAG_UNIT_POSITION}
         )
 
+    @property
+    def exists(self) -> bool:
+        """Whether or not the unit exists in Wialon."""
+        return bool(
+            self.session.wialon_api.core_search_item(
+                **{"id": self.id, "flags": flags.DATAFLAG_UNIT_BASE}
+            ).get("item", False)
+        )
+
     @property
     def available_commands(self) -> dict:
+        """Assigned commands to the unit."""
         return self.session.wialon_api.core_get_hw_cmds(
             **{"deviceTypeId": 0, "unitId": self.id}
         )
 
     @property
     def image_uri(self) -> str:
+        """An image URI for the unit."""
         return self._image_uri
 
     @property
     def imei_number(self) -> int | None:
+        """The unit's IMEI number."""
         if self._imei_number:
             return int(self._imei_number)
 
     @property
     def active(self) -> bool:
+        """Whether or not the unit is active."""
         if self._active:
             return bool(self._active)
         return False
@@ -85,7 +102,7 @@ class WialonUnit(WialonBase):
         param: dict | None = None,
     ) -> None:
         """
-        Executes a command on this Wialon unit.
+        Executes a command on the unit.
 
         :param name: A Wialon command name.
         :type name: :py:obj:`str`
@@ -115,7 +132,7 @@ class WialonUnit(WialonBase):
 
     def set_access_password(self, password: str) -> None:
         """
-        Sets a new access password for this Wialon unit.
+        Sets a new access password for the unit.
 
         :param password: A new access password.
         :type name: :py:obj:`str`
@@ -131,7 +148,7 @@ class WialonUnit(WialonBase):
 
     def activate(self) -> None:
         """
-        Activates this Wialon unit.
+        Activates the unit.
 
         :raises WialonError: If something goes wrong with Wialon.
         :returns: Nothing.
@@ -145,7 +162,7 @@ class WialonUnit(WialonBase):
 
     def deactivate(self) -> None:
         """
-        Deactivates this Wialon unit.
+        Deactivates the unit.
 
         :raises WialonError: If something goes wrong with Wialon.
         :returns: Nothing.
@@ -159,7 +176,7 @@ class WialonUnit(WialonBase):
 
     def assign_phone(self, phone: str) -> None:
         """
-        Assigns a phone number to this Wialon unit.
+        Assigns a phone number to the unit.
 
         :param phone: A phone number beginning with a country code.
         :type phone: :py:obj:`str`
@@ -200,13 +217,11 @@ class WialonUnit(WialonBase):
 
     def clean_phone_numbers(self, phones: list[str]) -> list[str]:
         """Takes a list of phone numbers and returns a list of clean phone numbers."""
-        cleaned_phones = []
-        for num in phones:
-            if "," in num:
-                cleaned_phones.extend(num.split(","))
-            else:
-                cleaned_phones.append(num)
-        return cleaned_phones
+        return [
+            clean_num
+            for num in phones
+            for clean_num in (num.split(",") if "," in num else [num])
+        ]
 
     def _get_afield_phone_numbers(self, key: str = "to_number") -> list[str] | None:
         """
@@ -251,5 +266,5 @@ class WialonUnit(WialonBase):
             **{"unitId": self.id}
         )
         if response:
-            dirty_phones = [driver[0].get("ph") for _, driver in response.items()]
+            dirty_phones = [driver[0].get("ph") for driver in response.values()]
             return self.clean_phone_numbers(dirty_phones)
